@@ -2,10 +2,7 @@
 BetterLib is a useful collection of utilities for Python developers to use in their projects. It is licensed under the Unlicense, so you can use it in any project, commercial or otherwise, without any restrictions whatsoever. (Yes, that means you can steal it and pass it off as your own. I won't judge.)
 """
 
-from . import logging
-from . import config
-from . import ip
-from . import quik
+from . import logging, config, ip, quik
 
 if __name__ == '__main__':
     print("This module is not meant to be run directly.")
