@@ -1,9 +1,7 @@
 """
 The QuikServer class is a simple HTTP server that can be used to serve files and dynamically generated content.
 """
-from http.server import BaseHTTPRequestHandler, HTTPServer, SimpleHTTPRequestHandler
-from . import config
-
+from http.server import BaseHTTPRequestHandler, HTTPServer
 
 QUIKVERSION = "0.2a"
 
